package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/PMGClass.class */
public final class PMGClass extends Attribute {
    private int pmgClassIndex;
    private int pmgIndex;

    /* JADX INFO: Access modifiers changed from: package-private */
    public PMGClass(int nameIndex, int length, DataInput input, ConstantPool constantPool) throws IOException {
        this(nameIndex, length, input.readUnsignedShort(), input.readUnsignedShort(), constantPool);
    }

    public PMGClass(int nameIndex, int length, int pmgIndex, int pmgClassIndex, ConstantPool constantPool) {
        super((byte) 9, nameIndex, length, constantPool);
        this.pmgIndex = pmgIndex;
        this.pmgClassIndex = pmgClassIndex;
    }

    public PMGClass(PMGClass pgmClass) {
        this(pgmClass.getNameIndex(), pgmClass.getLength(), pgmClass.getPMGIndex(), pgmClass.getPMGClassIndex(), pgmClass.getConstantPool());
    }

    @Override // org.apache.bcel.classfile.Attribute, org.apache.bcel.classfile.Node
    public void accept(Visitor v) {
        println("Visiting non-standard PMGClass object");
    }

    @Override // org.apache.bcel.classfile.Attribute
    public Attribute copy(ConstantPool constantPool) {
        return (Attribute) clone();
    }

    @Override // org.apache.bcel.classfile.Attribute
    public void dump(DataOutputStream file) throws IOException {
        super.dump(file);
        file.writeShort(this.pmgIndex);
        file.writeShort(this.pmgClassIndex);
    }

    public int getPMGClassIndex() {
        return this.pmgClassIndex;
    }

    public String getPMGClassName() {
        return super.getConstantPool().getConstantUtf8(this.pmgClassIndex).getBytes();
    }

    public int getPMGIndex() {
        return this.pmgIndex;
    }

    public String getPMGName() {
        return super.getConstantPool().getConstantUtf8(this.pmgIndex).getBytes();
    }

    public void setPMGClassIndex(int pmgClassIndex) {
        this.pmgClassIndex = pmgClassIndex;
    }

    public void setPMGIndex(int pmgIndex) {
        this.pmgIndex = pmgIndex;
    }

    @Override // org.apache.bcel.classfile.Attribute
    public String toString() {
        return "PMGClass(" + getPMGName() + ", " + getPMGClassName() + ")";
    }
}
